@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2017 Insecure.Com LLC ("The Nmap  *
+ * The Nmap Security Scanner is (C) 1996-2018 Insecure.Com LLC ("The Nmap  *
  * Project"). Nmap is also a registered trademark of the Nmap Project.     *
  * This program is free software; you may redistribute and/or modify it    *
  * under the terms of the GNU General Public License as published by the   *
@@ -90,12 +90,12 @@
  * Covered Software without special permission from the copyright holders. *
  *                                                                         *
  * If you have any questions about the licensing restrictions on using     *
- * Nmap in other works, are happy to help.  As mentioned above, we also    *
- * offer alternative license to integrate Nmap into proprietary            *
+ * Nmap in other works, we are happy to help.  As mentioned above, we also *
+ * offer an alternative license to integrate Nmap into proprietary         *
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
- * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@nmap.com for further *
+ * as providing support and updates.  They also fund the continued         *
+ * development of Nmap.  Please email sales@nmap.com for further           *
  * information.                                                            *
  *                                                                         *
  * If you have received a written license agreement or contract for        *
@@ -129,7 +129,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.h 36788 2017-06-07 12:32:38Z dmiller $ */
+/* $Id: Target.h 37126 2018-01-28 21:18:17Z fyodor $ */
 
 #ifndef TARGET_H
 #define TARGET_H
@@ -329,9 +329,8 @@ class Target {
   std::list <TracerouteHop> traceroute_hops;
 
   /* If the address for this target came from a DNS lookup, the list of
-     resultant addresses (sometimes there are more than one). The address
-     actually used is always the first element in this list. */
-  std::list<struct sockaddr_storage> resolved_addrs;
+     resultant addresses (sometimes there are more than one) that were not scanned. */
+  std::list<struct sockaddr_storage> unscanned_addrs;
 
 #ifndef NOLUA
   ScriptResults scriptResults;
